slidingpuzzle.nn package
========================

.. automodule:: slidingpuzzle.nn
   :members:
   :undoc-members:

Submodules
----------

slidingpuzzle.nn.dataset module
-------------------------------

.. automodule:: slidingpuzzle.nn.dataset
   :members:
   :undoc-members:

slidingpuzzle.nn.eval module
----------------------------

.. automodule:: slidingpuzzle.nn.eval
   :members:
   :undoc-members:

slidingpuzzle.nn.heuristics module
----------------------------------

.. automodule:: slidingpuzzle.nn.heuristics
   :members:
   :undoc-members:

slidingpuzzle.nn.models module
------------------------------

.. automodule:: slidingpuzzle.nn.models
   :members:
   :undoc-members:

slidingpuzzle.nn.paths module
-----------------------------

.. automodule:: slidingpuzzle.nn.paths
   :members:
   :undoc-members:

slidingpuzzle.nn.train module
-----------------------------

.. automodule:: slidingpuzzle.nn.train
   :members:
   :undoc-members:
